@@ -1,8 +1,10 @@
 # -*- coding: utf-8 -*-
 from django import forms
+from django.conf import settings
 from django.contrib.auth import authenticate
 from django.utils.translation import ugettext_lazy as _
 from django_nopassword.models import LoginCode
+from django_nopassword.utils import USERNAME_FIELD
 
 
 class AuthenticationForm(forms.Form):
@@ -20,6 +22,18 @@ class AuthenticationForm(forms.Form):
         'inactive': _("This account is inactive."),
     }
 
+    class Media:
+        if getattr(settings, 'NOPASSWORD_AUTOCOMPLETE', False):
+            js = (
+                'http://code.jquery.com/jquery-1.9.1.min.js',
+                '/static/js/hogan.js',
+                '/static/js/typeahead.js',
+                '/static/js/login.js',
+            )
+            css = {
+                'all': ('/static/css/login.css', )
+            }
+
     def __init__(self, request=None, *args, **kwargs):
         """
         If request is passed in, the form will validate that cookies are
@@ -30,12 +44,13 @@ class AuthenticationForm(forms.Form):
         self.request = request
         self.user_cache = None
         super(AuthenticationForm, self).__init__(*args, **kwargs)
+        self.fields['username'].label = _(USERNAME_FIELD.capitalize())
 
     def clean(self):
         username = self.cleaned_data.get('username')
 
         if username:
-            self.user_cache = authenticate(username=username)
+            self.user_cache = authenticate(**{USERNAME_FIELD: username})
             if self.user_cache is None:
                 raise forms.ValidationError(
                     self.error_messages['invalid_login'])
